@@ -1,7 +1,6 @@
 from __future__ import annotations
 from functools import wraps as functools_wraps
 import inspect
-from dataclasses import is_dataclass
 from weakref import WeakValueDictionary
 from typing import Any, TYPE_CHECKING
 
@@ -42,6 +41,7 @@ if TYPE_CHECKING:
     from ._gui._function_gui import FunctionGuiPlus
     from .types import WidgetTypeStr, PopUpModeStr, ErrorModeStr
     from .help import HelpWidget
+    from macrokit import Macro
 
 _BASE_CLASS_SUFFIX = "_Base"
 
@@ -136,8 +136,6 @@ def magicclass(
     def wrapper(cls) -> type[ClassGui]:
         if not isinstance(cls, type):
             raise TypeError(f"magicclass can only wrap classes, not {type(cls)}")
-        elif is_dataclass(cls):
-            raise TypeError("dataclass is not compatible with magicclass.")
 
         class_gui = _TYPE_MAP[widget_type]
 
@@ -394,8 +392,6 @@ def _call_magicmenu(
     def wrapper(cls) -> type[menugui_class]:
         if not isinstance(cls, type):
             raise TypeError(f"magicclass can only wrap classes, not {type(cls)}")
-        elif is_dataclass(cls):
-            raise TypeError("dataclass is not compatible with magicclass.")
 
         if not issubclass(cls, MagicTemplate):
             check_override(cls)
@@ -520,6 +516,9 @@ def get_function_gui(ui: MagicTemplate, name: str) -> FunctionGuiPlus:
     if not hasattr(widget, "mgui"):
         raise TypeError(f"Widget {widget} does not have FunctionGui inside it.")
 
+    if widget.mgui is not None:
+        return widget.mgui
+
     from ._gui._base import _build_mgui, _create_gui_method
 
     func = _create_gui_method(ui, func)
@@ -527,10 +526,6 @@ def get_function_gui(ui: MagicTemplate, name: str) -> FunctionGuiPlus:
     return mgui
 
 
-# def capitalize(cls: type[MagicTemplate]):
-#     ...
-
-
 def redo(ui: MagicTemplate, index: int = -1) -> None:
     """
     Redo operation on GUI using recorded macro.
@@ -544,21 +539,86 @@ def redo(ui: MagicTemplate, index: int = -1) -> None:
         By default the last operation will be redone.
     """
     line = ui.macro[index]
-    line.eval({"ui": ui})
+    try:
+        line.eval({"ui": ui})
+    except Exception as e:
+        msg = e.args[0]
+        msg = f"Caused by >>> {line}. {msg}"
+        raise e
     return None
 
 
-# def update_widget(ui: MagicTemplate) -> None:
-#     from macrokit import Head, Expr, Mock
-#     for expr in ui.macro:
-#         if expr.head == Head.call:
-#             target = expr.args[0]
-#             target_widget = Expr(Head.getitem, [target.args[0], str(target.args[1])])
-#             mock = Mock(target_widget)
-#             e = Expr(Head.call, [mock.mgui.update] + expr.args[1:])
+def update_widget_state(ui: MagicTemplate, macro: Macro | str | None = None) -> None:
+    """
+    Update widget values based on a macro.
 
-#         elif expr.head == Head.assign:
-#             expr.eval({}, {str(ui._my_symbol): ui})
+    This helper function works similar to the ``update_widget`` method of ``FunctionGui``.
+    In most cases, this function will be used for restoring a state from a macro recorded
+    before. Value changed signal will not be emitted within this operation.
+
+    Parameters
+    ----------
+    ui : MagicTemplate
+        Magic class instance.
+    macro : Macro or str, optional
+        An executable macro or string that dictates how GUI will be updated.
+    """
+    from macrokit import Head, Expr, Macro
+
+    if macro is None:
+        macro = ui.macro
+    elif isinstance(macro, str):
+        s = macro
+        macro = Macro()
+        for line in s.split("\n"):
+            macro.append(line)
+    elif not isinstance(macro, Macro):
+        raise TypeError(
+            f"The second argument must be a Macro or str, got {type(macro)}."
+        )
+
+    for expr in macro:
+        if expr.head == Head.call:
+            # ui.func(...)
+            ui_f, *arguments = expr.args
+            fname = str(ui_f.args[1])
+            if fname.startswith("_"):
+                if fname != "_call_with_return_callback":
+                    continue
+                args, kwargs = _arguments_to_values(arguments)
+                fgui = get_function_gui(ui, args[0])
+
+            else:
+                args, kwargs = _arguments_to_values(arguments)
+                fgui = get_function_gui(ui, fname)
+
+            with fgui.changed.blocked():
+                for key, value in kwargs.items():
+                    getattr(fgui, key).value = value
+
+        elif expr.head == Head.assign:
+            # ui.field.value = ...
+            # ui.vfield = ...
+            expr.eval({}, {str(ui._my_symbol): ui})
+
+    return None
+
+
+def _tuple(*args) -> tuple:
+    return args
+
+
+def _arguments_to_values(arguments) -> tuple[tuple, dict[str, Any]]:
+    from macrokit import Head, Expr, symbol
+
+    for i, arg in enumerate(arguments):
+        if isinstance(arg, Expr) and arg.head == Head.kw:
+            break
+    args = arguments[:i]
+    kwargs: list[Expr] = arguments[i:]
+    args = Expr(Head.call, [_tuple] + args).eval({symbol(_tuple): _tuple})
+    kwargs = Expr(Head.call, [dict] + kwargs).eval()
+    return args, kwargs
 
 
 class Parameters:
