@@ -19,6 +19,7 @@ from .mouse_event import MouseClickEvent
 from .._shared_utils import convert_color_code, to_rgba
 from .._doc import write_docs
 from ...widgets.utils import FreeWidget
+from ..._app import get_app
 
 BOTTOM = "bottom"
 LEFT = "left"
@@ -30,6 +31,12 @@ class LayerList(MutableSequence[LayerItem]):
     def __init__(self, parent: HasDataItems):
         self.parent = parent
 
+    def __repr__(self) -> str:
+        if len(self) == 0:
+            return f"{type(self).__name__}()"
+        s = ",\n\t".join(repr(layer) for layer in self)
+        return f"{type(self).__name__}(\n\t{s}\n)"
+
     def __getitem__(self, key: int | str) -> LayerItem:
         if isinstance(key, int):
             return self.parent._items[key]
@@ -649,6 +656,7 @@ class PlotItem(HasViewBox):
 
     @property
     def title(self) -> str:
+        """Title text of the graph."""
         return self.pgitem.titleLabel.text
 
     @title.setter
@@ -761,6 +769,7 @@ class ImageItem(HasViewBox):
 
     @property
     def title(self) -> str:
+        """Title text of the graph."""
         return self._title.text
 
     @title.setter
@@ -769,6 +778,7 @@ class ImageItem(HasViewBox):
 
     @property
     def xlabel(self) -> str:
+        """Label of X-axis."""
         return self._xlabel.text
 
     @xlabel.setter
@@ -777,6 +787,7 @@ class ImageItem(HasViewBox):
 
     @property
     def ylabel(self) -> str:
+        """Label of Y-axis."""
         return self._ylabel.text
 
     @xlabel.setter
@@ -790,6 +801,7 @@ class ImageItem(HasViewBox):
 
     @property
     def lock_contrast_limits(self):
+        """True if enable auto-contrast."""
         return self._lock_contrast_limits
 
     @lock_contrast_limits.setter
@@ -875,11 +887,10 @@ class HasBackground(FreeWidget):
 
 
 class QtPlotCanvas(HasBackground, PlotItem):
-    """
-    A 1-D data viewer that have similar API as napari Viewer.
-    """
+    """A 1-D data viewer that have similar API as napari Viewer."""
 
     def __init__(self, **kwargs):
+        app = get_app()
         # prepare widget
         PlotItem.__init__(self)
         self.layoutwidget = pg.GraphicsLayoutWidget()
@@ -891,7 +902,10 @@ class QtPlotCanvas(HasBackground, PlotItem):
 
 
 class QtImageCanvas(HasBackground, ImageItem):
+    """A 2-D image viewer that have similar API as napari Viewer."""
+
     def __init__(self, lock_contrast_limits: bool = False, **kwargs):
+        app = get_app()
         # prepare widget
         ImageItem.__init__(self, lock_contrast_limits=lock_contrast_limits)
         self.layoutwidget = pg.GraphicsLayoutWidget()
@@ -912,7 +926,10 @@ class QtImageCanvas(HasBackground, ImageItem):
 
 
 class Qt2YPlotCanvas(HasBackground):
+    """A plot canvas with two Y-axis."""
+
     def __init__(self, **kwargs):
+        app = get_app()
         self.layoutwidget = pg.GraphicsLayoutWidget()
 
         item_l = PlotItem()
@@ -952,8 +969,8 @@ class _MultiPlot(HasBackground, Generic[_C]):
 
     def __init__(
         self,
-        nrows: int = 0,
-        ncols: int = 0,
+        nrows: int = 1,
+        ncols: int = 1,
         sharex: bool = False,
         sharey: bool = False,
         **kwargs,
@@ -964,15 +981,16 @@ class _MultiPlot(HasBackground, Generic[_C]):
 
         Parameters
         ----------
-        nrows : int, default is 0
+        nrows : int, default is 1
             Initial rows of axes.
-        ncols : int, default is 0
+        ncols : int, default is 1
             Initail columns of axes.
         sharex : bool, default is False
             If true, all the x-axes will be linked.
         sharey : bool, default is False
             If true, all the y-axes will be linked.
         """
+        app = get_app()
         self.layoutwidget = pg.GraphicsLayoutWidget()
         self._axes: list[_C] = []
         self._sharex = sharex
