@@ -287,7 +287,7 @@ class MagicField(_FieldObject, Generic[_W, _V]):
         return _func
 
     @overload
-    def __get__(self, obj: Literal[None], objtype=None) -> MagicField[_W, _V] | _W:
+    def __get__(self, obj: Literal[None], objtype=None) -> MagicField[_W, _V]:
         ...
 
     @overload
@@ -890,7 +890,7 @@ def _define_callback_gui(self: MagicTemplate, callback: Callable):
             current_self = self
             while not (
                 hasattr(current_self, funcname)
-                and current_self.__class__.__name__ == clsname
+                and current_self.__class__.__qualname__.split(".")[-1] == clsname
             ):
                 current_self = current_self.__magicclass_parent__
             _func = _normalize_argcount(getattr(current_self, funcname))
