@@ -29,9 +29,10 @@ from .qtsignal import QtSignal
 if TYPE_CHECKING:
     from .._gui import BaseGui
     from .._gui.mgui_ext import PushButtonPlus, Action
+    from .._gui._macro import GuiMacro
     from ..fields import MagicField
 
-__all__ = ["thread_worker", "Timer"]
+__all__ = ["thread_worker", "Timer", "Callback"]
 
 
 class ProgressDict(TypedDict):
@@ -86,7 +87,7 @@ _R1 = TypeVar("_R1")
 _R2 = TypeVar("_R2")
 
 
-class Callbacks(Generic[_R1]):
+class CallbackList(Generic[_R1]):
     """List of callback functions."""
 
     def __init__(self):
@@ -386,12 +387,12 @@ class thread_worker:
     ) -> None:
         self._func: Callable[_P, _R1] | None = None
         self._callback_dict_ = {
-            "started": Callbacks(),
-            "returned": Callbacks(),
-            "errored": Callbacks(),
-            "yielded": Callbacks(),
-            "finished": Callbacks(),
-            "aborted": Callbacks(),
+            "started": CallbackList(),
+            "returned": CallbackList(),
+            "errored": CallbackList(),
+            "yielded": CallbackList(),
+            "finished": CallbackList(),
+            "aborted": CallbackList(),
         }
 
         self._ignore_errors = ignore_errors
@@ -445,6 +446,14 @@ class thread_worker:
         cls._DEFAULT_PROGRESS_BAR = pbar_cls
         return pbar_cls
 
+    @staticmethod
+    def to_callback(callback: Callable, *args, **kwargs) -> Callback:
+        """Convert a callback to a callback object."""
+        cb = Callback(callback)
+        if args or kwargs:
+            cb = cb(*args, **kwargs)
+        return cb
+
     @property
     def is_generator(self) -> bool:
         """True if bound function is a generator function."""
@@ -452,6 +461,7 @@ class thread_worker:
 
     @property
     def __doc__(self) -> str:
+        """Synchronize docstring with bound function."""
         return self.func.__doc__
 
     @__doc__.setter
@@ -618,13 +628,14 @@ class thread_worker:
         params = list(sig.parameters.values())[1:]
         return sig.replace(parameters=params)
 
-    def _bind_callbacks(self, worker: FunctionWorker | GeneratorWorker, gui):
+    def _bind_callbacks(self, worker: FunctionWorker | GeneratorWorker, gui: BaseGui):
         # bind callbacks
         is_generator = isinstance(worker, GeneratorWorker)
         for c in self.started._iter_as_method(gui):
             worker.started.connect(c)
         for c in self.returned._iter_as_method(gui):
             worker.returned.connect(c)
+        worker.returned.connect(partial(Callback.catch, macro=gui.macro))
         for c in self.errored._iter_as_method(gui):
             worker.errored.connect(c)
         for c in self.finished._iter_as_method(gui):
@@ -635,6 +646,7 @@ class thread_worker:
                 worker.aborted.connect(c)
             for c in self.yielded._iter_as_method(gui):
                 worker.yielded.connect(c)
+            worker.yielded.connect(partial(Callback.catch, macro=gui.macro))
 
     @property
     def __signature__(self) -> inspect.Signature:
@@ -687,22 +699,22 @@ class thread_worker:
         return _pbar
 
     @property
-    def started(self) -> Callbacks[None]:
+    def started(self) -> CallbackList[None]:
         """Event that will be emitted on started."""
         return self._callback_dict_["started"]
 
     @property
-    def returned(self) -> Callbacks[_R1]:
+    def returned(self) -> CallbackList[_R1]:
         """Event that will be emitted on returned."""
         return self._callback_dict_["returned"]
 
     @property
-    def errored(self) -> Callbacks[Exception]:
+    def errored(self) -> CallbackList[Exception]:
         """Event that will be emitted on errored."""
         return self._callback_dict_["errored"]
 
     @property
-    def yielded(self) -> Callbacks[_R1]:
+    def yielded(self) -> CallbackList[_R1]:
         """Event that will be emitted on yielded."""
         if not self.is_generator:
             raise TypeError(
@@ -712,12 +724,12 @@ class thread_worker:
         return self._callback_dict_["yielded"]
 
     @property
-    def finished(self) -> Callbacks[None]:
+    def finished(self) -> CallbackList[None]:
         """Event that will be emitted on finished."""
         return self._callback_dict_["finished"]
 
     @property
-    def aborted(self) -> Callbacks[None]:
+    def aborted(self) -> CallbackList[None]:
         """Event that will be emitted on aborted."""
         if not self.is_generator:
             raise TypeError(
@@ -751,3 +763,27 @@ def increment(pbar: ProgressBarLike):
     else:
         pbar.value += 1
     return None
+
+
+class Callback:
+    """Callback object that can be recognized by thread_worker."""
+
+    def __init__(self, f: Callable[[], Any]):
+        if not callable(f):
+            raise TypeError(f"{f} is not callable.")
+        self._func = f
+
+    @staticmethod
+    def catch(out, macro: GuiMacro):
+        if isinstance(out, Callback):
+            with macro.blocked():
+                out._func()
+
+    def __call__(self, *args, **kwargs) -> Callback:
+        """Return a partial callback."""
+        return self.__class__(partial(self._func, *args, *kwargs))
+
+    def __get__(self, obj, type=None) -> Callback:
+        if obj is None:
+            return self
+        return self(obj)
